#!/usr/bin/env python

import xlrd
import re
import decimal as dec
import argparse

# Used to quantize (round) Decimals
QTZ = dec.Decimal('0.01')
def decq(num, rounding=dec.ROUND_DOWN):
	return dec.Decimal(num).quantize(QTZ, rounding)

# Options
class Options:
	def __init__(self):
		# Column separator, default: comma
		self.separator = ','
		# File name to convert
		self.fileName = None

options = Options()

def parse_opts():
	parser = argparse.ArgumentParser(description="Convert Carrefour's VMS data to CSV")
	parser.add_argument('-t', '--tabs', dest='usetabs',
		action='store_const', const=True, default=False,
		help='Use tab as column separator instead of comma')
	parser.add_argument('file', metavar='FILENAME')
	progArgs = parser.parse_args()

	if progArgs.usetabs:
		options.separator = "\t"

	options.fileName = progArgs.file

if __name__ == '__main__':
	parse_opts()
	# Open book and worksheet
	book = xlrd.open_workbook(filename=options.fileName)
	sheet = book.sheet_by_index(0)

	# RegEx to get EAN13 code
	ean13RE = re.compile('^.+\s+([0-9]{13})$')

	# PPN rate
	ratePPN = dec.Decimal('0.1')

	i = 0
	validRows = 0
	while i < sheet.nrows:
		itemNo = None
		itemEAN13 = None
		qty = None
		harga = None
		
		if sheet.cell_type(i, 0) == xlrd.XL_CELL_NUMBER:
			itemNo = sheet.cell_value(i, 0)
			
		if sheet.cell_type(i, 2) == xlrd.XL_CELL_TEXT:
			itemDesc = sheet.cell_value(i, 2)
			m = ean13RE.match(itemDesc)
			if m:
				itemEAN13 = m.group(1)
		
		if sheet.cell_type(i, 5) == xlrd.XL_CELL_NUMBER:
			qty = decq(sheet.cell_value(i, 5))
		
		if sheet.cell_type(i, 6) == xlrd.XL_CELL_NUMBER:
			harga = decq(sheet.cell_value(i, 6), rounding=dec.ROUND_HALF_UP)
		
		if itemEAN13 and qty:
			subtotal = decq(qty * harga)
			ppn = decq(subtotal * ratePPN)
			afterTax = subtotal + ppn
			fmt = options.separator.join(['%d', '%s', '%d', '%.2f', '%.2f', '%.2f', '%.2f'])
			print fmt % (itemNo, itemEAN13, qty, harga, subtotal, ppn, afterTax)
			validRows = validRows + 1
		
		i = i + 1

		



